@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv6addr.h
- * Version    : $Id: libipv6addr.h,v 1.26 2007/04/26 09:57:31 peter Exp $
+ * Version    : $Id: libipv6addr.h,v 1.29 2007/08/11 07:07:36 peter Exp $
  * Copyright  : 2001-2007 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
@@ -84,6 +84,8 @@ typedef struct {
 #define IPV6_NEW_ADDR_PRODUCTIVE		(uint32_t) 0x00400000U
 #define IPV6_NEW_ADDR_6TO4_MICROSOFT		(uint32_t) 0x00800000U
 #define IPV6_NEW_ADDR_TEREDO			(uint32_t) 0x01000000U
+#define IPV6_NEW_ADDR_ORCHID			(uint32_t) 0x02000000U  /* RFC 4843 */
+#define IPV6_NEW_ADDR_LINKLOCAL_TEREDO		(uint32_t) 0x04000000U
 
 /* Registries */
 #define IPV6_ADDR_REGISTRY_6BONE	0x01
@@ -122,7 +124,9 @@ typedef struct {
 	{ IPV6_NEW_ADDR_ISATAP		, "ISATAP" },
 	{ IPV6_NEW_ADDR_PRODUCTIVE	, "productive" },
 	{ IPV6_NEW_ADDR_6TO4_MICROSOFT	, "6to4-microsoft" },
-	{ IPV6_NEW_ADDR_TEREDO		, "teredo" }
+	{ IPV6_NEW_ADDR_TEREDO		, "teredo" },
+	{ IPV6_NEW_ADDR_ORCHID		, "orchid" },
+	{ IPV6_NEW_ADDR_LINKLOCAL_TEREDO, "link-local-teredo" }
 };
 
 typedef struct {
@@ -167,8 +171,7 @@ extern int  addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, i
 
 extern int  libipv6addr_ipv6addrstruct_to_uncompaddr(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const uint32_t formatoptions);
 extern int  libipv6addr_to_octal(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const uint32_t formatoptions);
-
-/* extern int  ipv6addrstruct_to_fulluncompaddr(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring);*/ /* going obsolete */
+extern int  libipv6addr_to_hex(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const uint32_t formatoptions);
 
 extern void ipv6addrstruct_maskprefix(ipv6calc_ipv6addr *ipv6addrp);
 extern void ipv6addrstruct_masksuffix(ipv6calc_ipv6addr *ipv6addrp);
